==> haskell-ghc-source-gen-0.4.4.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-source-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-source-gen
version:              0.4.4.1
visibility:           public
id:                   ghc-source-gen-0.4.4.1-IgYGJI9I9SF43tzQsFh4Yp
key:                  ghc-source-gen-0.4.4.1-IgYGJI9I9SF43tzQsFh4Yp
license:              BSD-3-Clause
copyright:            Google LLC
maintainer:           judahjacobson@google.com
author:               Judah Jacobson
homepage:             https://github.com/google/ghc-source-gen#readme
synopsis:             Constructs Haskell syntax trees for the GHC API.
description:
    @ghc-source-gen@ is a library for generating Haskell source code.
    It uses the <https://hackage.haskell.org/package/ghc ghc> library
    to support recent language extensions, and provides a simple, consistent
    interface across several major versions of GHC.

    To get started, take a look at the "GHC.SourceGen" module.

    For more information, please see the <https://github.com/google/ghc-source-gen README>.

category:             Development
abi:                  68dd371e54f701e0a7b37cba12e8d518
exposed:              True
exposed-modules:
    GHC.SourceGen GHC.SourceGen.Binds GHC.SourceGen.Decl
    GHC.SourceGen.Expr GHC.SourceGen.Lit GHC.SourceGen.Module
    GHC.SourceGen.Name GHC.SourceGen.Overloaded GHC.SourceGen.Pat
    GHC.SourceGen.Pat.Internal GHC.SourceGen.Pretty GHC.SourceGen.Type

hidden-modules:
    GHC.SourceGen.Binds.Internal GHC.SourceGen.Expr.Internal
    GHC.SourceGen.Lit.Internal GHC.SourceGen.Name.Internal
    GHC.SourceGen.Syntax.Internal GHC.SourceGen.Type.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-source-gen-0.4.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-source-gen-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-source-gen
hs-libraries:         HSghc-source-gen-0.4.4.1-IgYGJI9I9SF43tzQsFh4Yp
depends:              base-4.16.4.0 ghc-9.2.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-source-gen/html/ghc-source-gen.haddock

haddock-html:         /usr/share/doc/haskell-ghc-source-gen/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-source-gen-0.4.5.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-source-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-source-gen
version:              0.4.5.0
visibility:           public
id:                   ghc-source-gen-0.4.5.0-1xftAoXnmdE7QAy0Q0UyFC
key:                  ghc-source-gen-0.4.5.0-1xftAoXnmdE7QAy0Q0UyFC
license:              BSD-3-Clause
copyright:            Google LLC
maintainer:           judahjacobson@google.com
author:               Judah Jacobson
homepage:             https://github.com/google/ghc-source-gen#readme
synopsis:             Constructs Haskell syntax trees for the GHC API.
description:
    @ghc-source-gen@ is a library for generating Haskell source code.
    It uses the <https://hackage.haskell.org/package/ghc ghc> library
    to support recent language extensions, and provides a simple, consistent
    interface across several major versions of GHC.

    To get started, take a look at the "GHC.SourceGen" module.

    For more information, please see the <https://github.com/google/ghc-source-gen README>.

category:             Development
abi:                  c1956f0905ef0a200c76952d192cd826
exposed:              True
exposed-modules:
    GHC.SourceGen GHC.SourceGen.Binds GHC.SourceGen.Decl
    GHC.SourceGen.Expr GHC.SourceGen.Lit GHC.SourceGen.Module
    GHC.SourceGen.Name GHC.SourceGen.Overloaded GHC.SourceGen.Pat
    GHC.SourceGen.Pat.Internal GHC.SourceGen.Pretty GHC.SourceGen.Type

hidden-modules:
    GHC.SourceGen.Binds.Internal GHC.SourceGen.Expr.Internal
    GHC.SourceGen.Lit.Internal GHC.SourceGen.Name.Internal
    GHC.SourceGen.Syntax.Internal GHC.SourceGen.Type.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-source-gen-0.4.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-source-gen-0.4.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-source-gen
hs-libraries:         HSghc-source-gen-0.4.5.0-1xftAoXnmdE7QAy0Q0UyFC
depends:              base-4.16.4.0 ghc-9.2.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-source-gen/html/ghc-source-gen.haddock

haddock-html:         /usr/share/doc/haskell-ghc-source-gen/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
